[Commits] [SCM] claws branch, master, updated. 3.14.1-230-g3f01dc8
wwp at claws-mail.org
wwp at claws-mail.org
Sat Mar 18 00:22:28 CET 2017
The branch, master has been updated
via 3f01dc8712d823923662ced3fca64e5cb60bb214 (commit)
from da399f43f30dd459dbdfe5b4f28c1baa8ac9d0a0 (commit)
Summary of changes:
src/common/utils.c | 4 ++--
src/etpan/imap-thread.c | 2 +-
src/matcher.c | 4 ++--
src/mimeview.c | 4 ++--
src/plugins/notification/gtkhotkey/gtk-hotkey-info.c | 2 +-
src/plugins/rssyl/rssyl_subscribe.c | 2 +-
6 files changed, 9 insertions(+), 9 deletions(-)
- Log -----------------------------------------------------------------
commit 3f01dc8712d823923662ced3fca64e5cb60bb214
Author: wwp <wwp at free.fr>
Date: Sat Mar 18 00:21:50 2017 +0100
Fix typos, fixes bug 3786: typo in src/mimeview.c.
diff --git a/src/etpan/imap-thread.c b/src/etpan/imap-thread.c
index f12f5de..093f78a 100644
--- a/src/etpan/imap-thread.c
+++ b/src/etpan/imap-thread.c
@@ -905,7 +905,7 @@ static void login_run(struct etpan_thread_op * op)
/* 7th argument has to be NULL here, to stop libetpan sending the
* a= attribute in its initial SCRAM-SHA-1 message to server. At least
* Dovecot 2.2 doesn't seem to like that, and will not authenticate
- * succesfully. */
+ * successfully. */
r = mailimap_authenticate(param->imap,
param->type, NULL, NULL, NULL,
NULL, param->login,
diff --git a/src/matcher.c b/src/matcher.c
index 89b6232..2756677 100644
--- a/src/matcher.c
+++ b/src/matcher.c
@@ -681,7 +681,7 @@ static void *matcher_test_thread(void *data)
*\param prop Pointer to matcher structure
*\param info Pointer to message info structure
*
- *\return gboolean TRUE if command was executed succesfully
+ *\return gboolean TRUE if command was executed successfully
*/
static gboolean matcherprop_match_test(const MatcherProp *prop,
MsgInfo *info)
@@ -1697,7 +1697,7 @@ static gboolean matcherlist_match_text_content(MatcherList *matchers, MimeInfo *
*\param matchers List of conditions
*\param fp Message file
*
- *\return gboolean TRUE if succesful match
+ *\return gboolean TRUE if successful match
*/
static gboolean matcherlist_match_body(MatcherList *matchers, gboolean body_only, MsgInfo *info)
{
diff --git a/src/mimeview.c b/src/mimeview.c
index add3796..305b5e5 100644
--- a/src/mimeview.c
+++ b/src/mimeview.c
@@ -1875,8 +1875,8 @@ static void mimeview_save_all_info(gint errors, gint total)
{
if (!errors) {
gchar *msg = g_strdup_printf(
- ngettext("%d file saved succesfully.",
- "%d files saved succesfully.",
+ ngettext("%d file saved successfully.",
+ "%d files saved successfully.",
total),
total);
alertpanel_notice(msg);
diff --git a/src/plugins/notification/gtkhotkey/gtk-hotkey-info.c b/src/plugins/notification/gtkhotkey/gtk-hotkey-info.c
index c956fb5..f091aea 100644
--- a/src/plugins/notification/gtkhotkey/gtk-hotkey-info.c
+++ b/src/plugins/notification/gtkhotkey/gtk-hotkey-info.c
@@ -158,7 +158,7 @@ gtk_hotkey_info_unbind (GtkHotkeyInfo* self, GError **error)
* @returns: %TRUE if gtk_hotkey_info_bind() has been called and returned %TRUE
* on this hotkey
*
- * Check whether the hotkey has been succesfully bound to a #GtkHotkeyListener.
+ * Check whether the hotkey has been successfully bound to a #GtkHotkeyListener.
*/
gboolean
gtk_hotkey_info_is_bound (GtkHotkeyInfo* self)
diff --git a/src/plugins/rssyl/rssyl_subscribe.c b/src/plugins/rssyl/rssyl_subscribe.c
index 41747e6..1014385 100644
--- a/src/plugins/rssyl/rssyl_subscribe.c
+++ b/src/plugins/rssyl/rssyl_subscribe.c
@@ -122,7 +122,7 @@ FolderItem *rssyl_subscribe(FolderItem *parent, const gchar *url,
g_free(sctx);
}
- /* OK, feed is succesfully fetched and correct, let's add it to CM. */
+ /* OK, feed is successfully fetched and correct, let's add it to CM. */
/* Create a folder for it. */
tmpname = rssyl_format_string(ctx->feed->title, TRUE, TRUE);
-----------------------------------------------------------------------
hooks/post-receive
diff --git a/src/common/utils.c b/src/common/utils.c
index df751e9..bf14edc 100644
--- a/src/common/utils.c
+++ b/src/common/utils.c
@@ -4085,7 +4085,7 @@ void replace_returns(gchar *str)
}
/* get_uri_part() - retrieves a URI starting from scanpos.
- Returns TRUE if succesful */
+ Returns TRUE if successful */
gboolean get_uri_part(const gchar *start, const gchar *scanpos,
const gchar **bp, const gchar **ep, gboolean hdr)
{
@@ -4182,7 +4182,7 @@ static gboolean is_toplvl_domain(GHashTable *tab, const gchar *first, const gcha
return g_hash_table_lookup(tab, buf) != NULL;
}
/* get_email_part() - retrieves an email address. Returns TRUE if succesful */
gboolean get_email_part(const gchar *start, const gchar *scanpos,
const gchar **bp, const gchar **ep, gboolean hdr)
{
@@ -4182,7 +4182,7 @@ static gboolean is_toplvl_domain(GHashTable *tab, const gchar *first, const gcha
return g_hash_table_lookup(tab, buf) != NULL;
}
-/* get_email_part() - retrieves an email address. Returns TRUE if succesful */
+/* get_email_part() - retrieves an email address. Returns TRUE if successful */
gboolean get_email_part(const gchar *start, const gchar *scanpos,
const gchar **bp, const gchar **ep, gboolean hdr)
--
Claws Mail
More information about the Commits
mailing list